==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/aa-ER/admin/settings/message.php <==
<?php

return [

    'update' => [
        'error'                 => 'crwdns826:0crwdne826:0',
        'success'               => 'crwdns827:0crwdne827:0',
    ],
    'backup' => [
        'delete_confirm'        => 'crwdns1423:0crwdne1423:0',
        'file_deleted'          => 'crwdns1424:0crwdne1424:0',
        'generated'             => 'crwdns1425:0crwdne1425:0',
        'file_not_found'        => 'crwdns1426:0crwdne1426:0',
        'restore_warning'       => 'crwdns6709:0crwdne6709:0',
        'restore_confirm'       => 'crwdns6711:0crwdne6711:0'
    ],
    'purge' => [
        'error'     => 'crwdns1615:0crwdne1615:0',
        'validation_failed'     => 'crwdns1616:0crwdne1616:0',
        'success'               => 'crwdns1617:0crwdne1617:0',
    ],
    'mail' => [
        'sending' => 'crwdns6713:0crwdne6713:0',
        'success' => 'crwdns6715:0crwdne6715:0',
        'error' => 'crwdns6717:0crwdne6717:0',
        'additional' => 'crwdns6719:0crwdne6719:0'
    ],
    'ldap' => [
        'testing' => 'crwdns6721:0crwdne6721:0',
        '500' => 'crwdns6723:0crwdne6723:0',
        'error' => 'crwdns6725:0crwdne6725:0',
        'sync_success' => 'crwdns6727:0crwdne6727:0',
        'testing_authentication' => 'crwdns6729:0crwdne6729:0',
        'authentication_success' => 'crwdns6731:0crwdne6731:0'
    ],
    'webhook' => [
        'sending' => 'crwdns11373:0crwdne11373:0',
        'success' => 'crwdns11841:0crwdne11841:0',
        'success_pt1' => 'crwdns11375:0crwdne11375:0',
        'success_pt2' => 'crwdns11377:0crwdne11377:0',
        '500' => 'crwdns11379:0crwdne11379:0',
        'error' => 'crwdns11381:0crwdne11381:0',
        'error_redirect' => 'crwdns11843:0crwdne11843:0',
        'error_misc' => 'crwdns11383:0crwdne11383:0',
    ]
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/aa-ER/admin/settings/message.php <==
<?php

return [

    'update' => [
        'error'                 => 'crwdns826:0crwdne826:0',
        'success'               => 'crwdns827:0crwdne827:0',
    ],
    'backup' => [
        'delete_confirm'        => 'crwdns1423:0crwdne1423:0',
        'file_deleted'          => 'crwdns1424:0crwdne1424:0',
        'generated'             => 'crwdns1425:0crwdne1425:0',
        'file_not_found'        => 'crwdns1426:0crwdne1426:0',
        'restore_warning'       => 'crwdns6709:0crwdne6709:0',
        'restore_confirm'       => 'crwdns6711:0crwdne6711:0'
    ],
    'restore' => [
        'success'               => 'crwdns12668:0crwdne12668:0'
    ],
    'purge' => [
        'error'     => 'crwdns1615:0crwdne1615:0',
        'validation_failed'     => 'crwdns1616:0crwdne1616:0',
        'success'               => 'crwdns1617:0crwdne1617:0',
    ],
    'mail' => [
        'sending' => 'crwdns6713:0crwdne6713:0',
        'success' => 'crwdns6715:0crwdne6715:0',
        'error' => 'crwdns6717:0crwdne6717:0',
        'additional' => 'crwdns6719:0crwdne6719:0'
    ],
    'ldap' => [
        'testing' => 'crwdns6721:0crwdne6721:0',
        '500' => 'crwdns6723:0crwdne6723:0',
        'error' => 'crwdns6725:0crwdne6725:0',
        'sync_success' => 'crwdns6727:0crwdne6727:0',
        'testing_authentication' => 'crwdns6729:0crwdne6729:0',
        'authentication_success' => 'crwdns6731:0crwdne6731:0'
    ],
    'webhook' => [
        'sending' => 'crwdns11373:0crwdne11373:0',
        'success' => 'crwdns11841:0crwdne11841:0',
        'success_pt1' => 'crwdns11375:0crwdne11375:0',
        'success_pt2' => 'crwdns11377:0crwdne11377:0',
        '500' => 'crwdns11379:0crwdne11379:0',
        'error' => 'crwdns11381:0crwdne11381:0',
        'error_redirect' => 'crwdns11843:0crwdne11843:0',
        'error_misc' => 'crwdns11383:0crwdne11383:0',
        'webhook_fail' => 'crwdns12830:0crwdne12830:0',
    ]
];
